IL-2 FB Commons
===============

|Build Status| |Coverage Status| |PyPi package| |PyPi downloads| |License|

Common helpers and data structures for projects related to
``IL-2 Forgotten Battles``.


.. |Build Status| image:: http://img.shields.io/travis/IL2HorusTeam/il2fb-commons.svg?style=flat&branch=master
   :target: https://travis-ci.org/IL2HorusTeam/il2fb-commons
.. |Coverage Status| image:: http://img.shields.io/coveralls/IL2HorusTeam/il2fb-commons.svg?style=flat&branch=master
   :target: https://coveralls.io/r/IL2HorusTeam/il2fb-commons?branch=master
.. |PyPi package| image:: http://img.shields.io/pypi/v/il2fb-commons.svg?style=flat
   :target: http://badge.fury.io/py/il2fb-commons/
.. |PyPi downloads| image::  http://img.shields.io/pypi/dm/il2fb-commons.svg?style=flat
   :target: https://crate.io/packages/il2fb-commons/
.. |License| image:: https://img.shields.io/badge/license-LGPLv3-brightgreen.svg?style=flat
   :target: http://badge.fury.io/py/il2fb-commons/
